pub struct PythonWorkerLogEntry {
pub sequence: u64,
pub stream: &'static str,
pub message: String,
}Expand description
One redacted, structured line emitted by a persistent Python worker.
Fields
sequence: u64stream: &'static strmessage: StringTrait Implementations
Sourceimpl Clone for PythonWorkerLogEntry
impl Clone for PythonWorkerLogEntry
Sourcefn clone(&self) -> PythonWorkerLogEntry
fn clone(&self) -> PythonWorkerLogEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PythonWorkerLogEntry
impl Debug for PythonWorkerLogEntry
Sourceimpl PartialEq for PythonWorkerLogEntry
impl PartialEq for PythonWorkerLogEntry
Sourcefn eq(&self, other: &PythonWorkerLogEntry) -> bool
fn eq(&self, other: &PythonWorkerLogEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PythonWorkerLogEntry
impl Serialize for PythonWorkerLogEntry
impl Eq for PythonWorkerLogEntry
impl StructuralPartialEq for PythonWorkerLogEntry